clear
set more off
***Stata Code for the Project "Does Competition Affect Bank Risk?" *******
use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

*** TABLE 3 
eststo clear
eststo: reghdfe log_TotalRisk logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk logDISNum $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TailRisk logDIS $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TailRisk logDISNum  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TailRisk log_new2_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TailRisk log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 est5 est6 est7 est8 using Table3.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 3. Competition and Bank Risk-Taking: Total Risk and Tail Risk") replace

*** TABLE 4
eststo clear
eststo: reghdfe log_AssRisk logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_AssRisk logDISNum   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_AssRisk log_new2_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_AssRisk log_newnum_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table4_1.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 4_1. Competition and Bank Risk-Taking: Asset Risk") replace

fsum log_AssRisk, s(N mean p25 median p75 min max sd)

sort bhcid year
merge 1:1 bhcid year using sample_ImpliedAssetVol_upd.dta
keep if _merge==3
drop _merge

eststo clear
eststo: reghdfe log_avol logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_avol logDISNum   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_avol log_new2_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_avol log_newnum_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table4_2.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 4_2. Competition and Bank Risk-Taking: Asset Risk") replace

fsum log_avol, s(N mean p25 median p75 min max sd)


*** TABLE 5 Panel A
use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

eststo clear
eststo: reghdfe wROA logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wROA logDISNum  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wROA log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wROA log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table5A_1.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 5 Panel A_1. Competition, Bank Profitability, and Bank Pricing Power") replace

eststo clear
eststo: reghdfe wEPSpi logDIS $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wEPSpi  logDISNum $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wEPSpi log_new2_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe wEPSpi  log_newnum_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table5A_2.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 5 Panel A_1. Competition, Bank Profitability, and Bank Pricing Power") replace

fsum wEPSpi, s(N mean p25 median p75 min max sd)

eststo clear
eststo: reghdfe Wintinc_costfund logDIS   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wintinc_costfund logDISNum $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wintinc_costfund log_new2_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wintinc_costfund log_newnum_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table5A_3.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 5 Panel A_1. Competition, Bank Profitability, and Bank Pricing Power") replace

fsum Wintinc_costfund, s(N mean p25 median p75 min max sd)



*** TABLE 5 Panel B
eststo clear
eststo: reghdfe logQ logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe logQ logDISNum  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe logQ log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe logQ log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table5B.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 5 Panel B. Competition and Bank Charter Value") replace

fsum logQ, s(N mean p25 median p75 min max sd)


*** TABLE 6
use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

set matsize 11000

eststo clear
eststo: reghdfe log_TotalRisk logDIS $CX_1 if dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk logDIS $CX_1 if ~dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk logDISNum $CX_1 if dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk logDISNum $CX_1 if ~dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_new2_bhc $CX_1 if dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_new2_bhc $CX_1 if ~dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_newnum_bhc $CX_1 if dum_retail, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_TotalRisk log_newnum_bhc $CX_1 if ~dum_retail, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 est5 est6 est7 est8 using Table6.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 6. Bank Competition and Total Risk – Differentiate with Retail Deposit Dependence") replace


set matsize 11000

xi: reg log_TotalRisk logDIS $CX_1 i.bhcid i.state_year if dum_retail
est store retail
xi: reg log_TotalRisk logDIS $CX_1 i.bhcid i.state_year if ~dum_retail
est store nonretail
suest retail nonretail, cluster(bhcid)
test [retail_mean = nonretail_mean]: logDIS
* chi2(  1) =    4.26
* Prob > chi2 =    0.0390

xi: reg log_TotalRisk logDISNum $CX_1 i.bhcid i.state_year if dum_retail
est store retail
xi: reg log_TotalRisk logDISNum $CX_1 i.bhcid i.state_year if ~dum_retail
est store nonretail
suest retail nonretail, cluster(bhcid)
test [retail_mean = nonretail_mean]: logDISNum
*chi2(  1) =    6.52
*Prob > chi2 =    0.0107
xi: reg log_TotalRisk log_new2_bhc $CX_1 i.bhcid i.state_year if dum_retail
est store retail
xi: reg log_TotalRisk log_new2_bhc $CX_1 i.bhcid i.state_year if ~dum_retail
est store nonretail
suest retail nonretail, cluster(bhcid)
test [retail_mean = nonretail_mean]: log_new2_bhc
*chi2(  1) =    4.85
*Prob > chi2 =    0.0276
xi: reg log_TotalRisk log_newnum_bhc $CX_1 i.bhcid i.state_year if dum_retail
est store retail
xi: reg log_TotalRisk log_newnum_bhc $CX_1 i.bhcid i.state_year if ~dum_retail
est store nonretail
suest retail nonretail, cluster(bhcid)
test [retail_mean = nonretail_mean]: log_newnum_bhc
*chi2(  1) =    4.77
*Prob > chi2 =    0.0289



*** TABLE 7
use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

eststo clear
eststo: reghdfe log_non9 logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_non9 logDISNum  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_non9 log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe log_non9 log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table7_1.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 7_1. Competition Effect on Noninterest Income and Short-Term Funding") replace


use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

eststo clear
eststo: reghdfe Wshort_dep logDIS $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wshort_dep logDISNum $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wshort_dep log_new2_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe Wshort_dep log_newnum_bhc $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table7_2.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 7_2. Competition Effect on Noninterest Income and Short-Term Funding") replace


*** TABLE 8
use bank_risk_data.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"

sort bhcid year
merge 1:1 bhcid year using SBA_indicator_upd.dta
drop if _merge==2
replace sba=0 if sba==.
drop _merge

eststo clear
eststo: reghdfe sba logDIS  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe sba logDISNum  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe sba log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe sba log_newnum_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3 est4 using Table8_1.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 8. Competition Effect on SBA Loans and Borrower Traits") replace

fsum sba, s(N mean p25 median p75 min max sd)


use bank_risk_borrower.dta, clear

egen state_year = group(state year)
global CX_1 "logSIZE_lag wDepAsset_lag wLoanAsset_lag wCAP_lag"


eststo clear
eststo: reghdfe  wfirm_ROA logDIS $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe  wfirm_ROA logDISNum   $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe  wfirm_ROA log_new2_bhc  $CX_1, a(bhcid state_year) cluster(state)  keepsin
eststo: reghdfe  wfirm_ROA log_newnum_bhc   $CX_1, a(bhcid state_year) cluster(state)  keepsin
esttab est1 est2 est3  est4  using Table8_2.csv, se b(%9.4f) r2(%9.4f) starlevels(* .1 ** .05 *** .01) nodepvars nomtitles title("Table 8. Competition Effect on SBA Loans and Borrower Traits") replace


fsum wfirm_ROA, s(N mean p25 median p75 min max sd)

exit
